==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE57S.sql <==
/****************************************************************************/
/* GE57 ( 雛形明細定義ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2016/10/27 10:56:53                                            */
/****************************************************************************/

CREATE TABLE GE57 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , LISTID           VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID       */
 , SHEETNO          INTEGER             DEFAULT 0   NOT NULL            /*  30 ｼｰﾄ番号      */
 , SHEETREF         VARCHAR (  30 )                 NOT NULL            /*  40 対応ｼｰﾄ番号  */
 , HEADDBID         VARCHAR (  20 )                                     /*  50 ﾍｯﾀﾞDBID     */
 , BODYDBID         VARCHAR (  20 )                                     /*  60 ﾎﾞﾃﾞｨDBID    */
 , LOOPCLM          VARCHAR (  30 )                                     /*  70 繰返必須ｶﾗﾑ  */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /*  80 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (  20 )                                     /*  90 設変番号     */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成社員     */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者       */
);

==> openGion7.2.4.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE57S.sql <==
/****************************************************************************/
/* GE57 ( 雛形明細定義ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2018/09/28 16:03:31                                            */
/****************************************************************************/

CREATE TABLE GE57 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , LISTID           VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID       */
 , SHEETNO          INTEGER             DEFAULT 0   NOT NULL            /*  30 ｼｰﾄ番号      */
 , SHEETREF         VARCHAR (  30 )                 NOT NULL            /*  40 対応ｼｰﾄ番号  */
 , HEADDBID         VARCHAR (  20 )                                     /*  50 ﾍｯﾀﾞDBID     */
 , BODYDBID         VARCHAR (  20 )                                     /*  60 ﾎﾞﾃﾞｨDBID    */
 , LOOPCLM          VARCHAR (  30 )                                     /*  70 繰返必須ｶﾗﾑ  */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /*  80 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (  20 )                                     /*  90 設変番号     */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成者       */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者       */
);
